<?php
/*
 * Plugin Name: Event Banner Widget
 * Plugin URI: http://www.smitka.net/event-banner
 * Description: Show Event as Side Banner
 * Version: 1.0
 * Author: Ivan Smitka
 * Author URI: http://www.smitka.net
 *
 * The MIT License
 *
 * Copyright 2022 Web4People Ivan Smitka <ivan at stimulus dot cz>.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 *
 */

/**
 * @author Ivan Smitka <ivan at stimulus dot cz>
 */
class WP_EventBanner
{
    private $show = false;
    private $eventStart = null;
    private $label = null;
    private $place = null;
    private $logo = null;
    private $logoSmall = null;
    private $countdown = false;
    private $link = null;
    private $linkLabel = "P&Rcaron;IHL&Aacute;SIT SE";
    private $collapsible = 1280;
    private $collapsed = 320;
    private $color = "#FFFFFF";

    /**
     */
    public static function init()
    {
        // Scripts
        if (!is_admin()) { // show only in public area
            add_action('wp_enqueue_scripts', array(
                'WP_EventBanner',
                'enqueue_scripts'));
            // shortcodes
            add_shortcode('event-banner', array(
                'WP_EventBanner',
                'main'));
        }
    }

    /**
     */
    public static function enqueue_scripts()
    {
        wp_enqueue_script('wp-event-banner', plugins_url('static/js/event-banner.js', __FILE__), array(
            'jquery'));
        wp_enqueue_style('wp-event-banner', plugins_url('static/css/event-banner.css', __FILE__), array());
    }

    /**
     * @param array $args
     * @return string
     */
    public static function main($args = array())
    {
        $eb = new WP_EventBanner($args);
        return $eb->render();
    }

    function __construct($args = array())
    {
        if (!is_array($args)) {
            $args = [];
        }
        $this->show = !array_key_exists('show', $args) || $args['show'] !== false;
        if (array_key_exists('collapsed', $args)) {
            $this->collapsed = intval($args['collapsed']);
        }
        if (array_key_exists('collapsible', $args)) {
            $this->collapsible = intval($args['collapsible']);
        }
        if ($this->show) {
            $this->show = false;
            if (class_exists("EM_Events")) {
                if (is_array($events = EM_Events::get())) {
                    $events = array_filter($events, function ($event) {
                        if ($event instanceof EM_Event) {
                            if (is_array($attrs = $event->event_attributes)) {
                                return !empty(array_filter($attrs, function ($value, $key) {
                                    return $key === 'EventBanner' && $value === "Ano";
                                }, ARRAY_FILTER_USE_BOTH));
                            }
                        }
                        return false;
                    });
                    if (count($events) > 0) {
                        foreach ($events as $event) {
                            /**
                             * @var EM_Event $event
                             */
                            $this->label = $event->event_name;
                            if ($location = $event->get_location()) {
                                $this->place = $location->location_name;
                            }
                            if ($eventStart = $event->start) {
                                $this->eventStart = new EM_DateTime($eventStart);
                            }
                            foreach ($event->event_attributes as $key => $value) {
                                switch ($key) {
                                    case 'EventBannerCountdown' :
                                        $this->countdown = $value === "Ano";
                                        break;
                                    case 'URL_Turnaj' :
                                        $this->link = $value;
                                        break;
                                }
                            }
                            /**
                             * @var EM_Category $category
                             */
                            foreach ($event->get_categories() as $category) {
                                if ($imageUrl = $category->get_image_url()) {
                                    $this->logo = "<img src='{$imageUrl}'>";
                                    if ($slug = $category->slug) {
                                        $this->logoSmall = "<img src='/wp-content/uploads/category/{$slug}.png'>";
                                    }
                                }
                            }
                            $this->show = true;
                            break;
                        }
                    }
                }
            }
        }
    }

    /**
     * @param string $place
     * @param EM_DateTime $eventStart
     * @return string
     */
    private function render()
    {
        if ($this->show) {
            $twoColumns = ($this->logo && ($this->eventStart || $this->place)) ? "columns-2" : "";
            ob_start();
            ?>
            <section class="EventBanner" style="display: none; background-color: <?= $this->color ?>;"
                     data-collapsible="<?= $this->collapsible ?>" data-collapsed="<?= $this->collapsed ?>"
                     <?php if ($this->link) { ?>data-link="<?= $this->link ?>"<?php } ?>>
                <div>
                    <section class="collapsed">
                        <div>
                            <div class="logo"><?php if ($this->logoSmall) { print $this->logoSmall; } else { print $this->label; } ?></div>
                            <div class="info">
                                <?php if ($this->eventStart) { ?><div class="date"><?= date('j. n. Y', $this->eventStart->getTimestamp()) ?></div><?php } ?>
                                <?php if ($this->place) { ?><div class="place"><?= $this->place ?></div><?php } ?>
                            </div>
                        </div>
                    </section>
                    <section class="expanded">
                        <div class="<?= $twoColumns ?>">
                            <?php if ($this->logo) { ?>
                                <div class="logo"><?= $this->logo ?></div><?php } ?>
                            <div class="text-center">
                                <?php if ($this->eventStart) { ?>
                                    <div class="date p"><?= date('j. n. Y', $this->eventStart->getTimestamp()) ?></div><?php } ?>
                                <?php if ($this->place) { ?>
                                    <div class="place p"><?= $this->place ?></div><?php } ?>
                                <?php if ($this->countdown && $this->eventStart) { ?>
                                <div class="p text-center clearfix"
                                     data-countdown="<?= $this->eventStart->getTimestamp() ?>"
                                     title="<?= date('j.n.Y H:m', $this->eventStart->getTimestamp()) ?>">
                                        <span class="days">0</span>d <span class="hours">0</span>h <span
                                                class="minutes">0</span>m <span class="seconds">0</span>s
                                    </div><?php } ?>
                            </div>
                        </div>
                        <div>
                            <?php if ($this->link) { ?>
                                <div class="">
                                <a href="<?= $this->link ?>"
                                   class="text-center clearfix link" target="_blank"><?= $this->linkLabel ?></a>
                                </div><?php } ?>
                        </div>
                        <a href="#" class="collapse"><i class="fas fa-times"></i></a>
                    </section>
                </div>
            </section>
            <?php
            return ob_get_clean();
        }
        return "";
    }

}

add_action('plugins_loaded', array(
    'WP_EventBanner',
    'init'), 100);
